def find_license_gitlab():
    """  """
